@@ -397,7 +397,7 @@ def convert(value: numeric, from_unit: str, to_unit: str, print_conversion_path:
         else:
             return None
     if print_conversion_path:
-        print("converting from '" + str(from_unit) + "' to '" + str(to_unit),
+        logging.info("converting from '" + str(from_unit) + "' to '" + str(to_unit),
               print_path(conv_path), sep='\n')
     return conv
 
@@ -408,7 +408,7 @@ def convert_for_SimPandas(value: numeric, from_unit: str, to_unit: str, print_co
     if convertible(from_unit, to_unit):
         conv, conv_path = _converter(value, from_unit, to_unit)
     if print_conversion_path and conv is not None:
-        print("converting from '" + str(from_unit) + "' to '" + str(to_unit),
+        logging.info("converting from '" + str(from_unit) + "' to '" + str(to_unit),
               print_path(conv_path), sep='\n')
     elif print_conversion_path and conv is not None:
         logging.warning("conversion not found, returning original values.")
