@@ -6,17 +6,17 @@ Created on Sat Oct 24 14:34:59 2020
 @author: Martín Carlos Araya <martinaraya@gmail.com>
 """
 
-__version__ = '0.5.2'
-__release__ = 20230107
-__all__ = ['Length', 'Area', 'Volume']
+__version__ = '0.5.3'
+__release__ = 20230118
+__all__ = ['Length', 'Area', 'Volume', 'Permeability']
 
-from unyts.dictionaries import dictionary
-from unyts.unit_class import Unit
-from unyts.helpers.common_classes import unit_or_str, numeric
+from ..dictionaries import dictionary as _dictionary
+from ..unit_class import Unit
+from ..helpers.common_classes import unit_or_str, numeric
 
 
 class Length(Unit):
-    classUnits = dictionary['Length']
+    classUnits = _dictionary['Length']
 
     def __init__(self, value: numeric, units: unit_or_str):
         self.name = 'length'
@@ -26,7 +26,7 @@ class Length(Unit):
 
 
 class Area(Unit):
-    classUnits = dictionary['Area']
+    classUnits = _dictionary['Area']
 
     def __init__(self, value: numeric, units: unit_or_str):
         self.name = 'area'
@@ -36,10 +36,20 @@ class Area(Unit):
 
 
 class Volume(Unit):
-    classUnits = dictionary['Volume']
+    classUnits = _dictionary['Volume']
 
     def __init__(self, value: numeric, units: unit_or_str):
         self.name = 'volume'
         self.kind = Volume
         self.value = self.check_value(value)
         self.unit = self.check_unit(units)
+
+
+class Permeability(Unit):
+    classUnits = _dictionary['Permeability']
+
+    def __init__(self, value: numeric, units: unit_or_str):
+        self.name = 'permeability'
+        self.kind = Permeability
+        self.value = self.check_value(value)
+        self.unit = self.check_unit(units)
