@@ -6,17 +6,17 @@ Created on Sat Oct 24 14:34:59 2020
 @author: Martín Carlos Araya <martinaraya@gmail.com>
 """
 
-__version__ = '0.5.2'
-__release__ = 20230107
+__version__ = '0.5.3'
+__release__ = 20230118
 __all__ = ['Density', 'VolumeRatio', 'ProductivityIndex', 'PressureGradient']
 
-from unyts.dictionaries import dictionary
-from unyts.unit_class import Unit
-from unyts.helpers.common_classes import unit_or_str, numeric
+from ..dictionaries import dictionary as _dictionary
+from ..unit_class import Unit
+from ..helpers.common_classes import unit_or_str, numeric
 
 
 class Density(Unit):
-    classUnits = dictionary['Density']
+    classUnits = _dictionary['Density']
 
     def __init__(self, value: numeric, units: unit_or_str):
         self.name = 'density'
@@ -26,30 +26,30 @@ class Density(Unit):
 
 
 class VolumeRatio(Unit):
-    classUnits = dictionary['VolumeRatio']
+    classUnits = _dictionary['VolumeRatio']
 
     def __init__(self, value: numeric, units: unit_or_str):
-        self.name = 'volumeRatio'
-        self.kid = VolumeRatio
+        self.name = 'volume_ratio'
+        self.kind = VolumeRatio
         self.value = self.check_value(value)
         self.unit = self.check_unit(units)
 
 
 class ProductivityIndex(Unit):
-    classUnits = dictionary['ProductivityIndex']
+    classUnits = _dictionary['ProductivityIndex']
 
     def __init__(self, value: numeric, units: unit_or_str):
-        self.name = 'productivityIndex'
+        self.name = 'productivity_index'
         self.kind = ProductivityIndex
         self.value = self.check_value(value)
         self.unit = self.check_unit(units)
 
 
 class PressureGradient(Unit):
-    classUnits = dictionary['PressureGradient']
+    classUnits = _dictionary['PressureGradient']
 
     def __init__(self, value: numeric, units: unit_or_str):
-        self.name = 'pressureGradient'
+        self.name = 'pressure_gradient'
         self.kind = PressureGradient
         self.value = self.check_value(value)
         self.unit = self.check_unit(units)
